Struct Ccipr4
#[repr(transparent)]pub struct Ccipr4(pub u32);Expand description
RCC kernel clock configuration register
Tuple Fields
0: u32Implementations
impl Ccipr4
impl Ccipr4
pub const fn octospi1sel(&self) -> Octospisel
pub const fn octospi1sel(&self) -> Octospisel
OCTOSPI1 kernel clock source selection Set and reset by software.
pub const fn set_octospi1sel(&mut self, val: Octospisel)
pub const fn set_octospi1sel(&mut self, val: Octospisel)
OCTOSPI1 kernel clock source selection Set and reset by software.
pub const fn systicksel(&self) -> Systicksel
pub const fn systicksel(&self) -> Systicksel
SYSTICK clock source selection Note: rcc_hclk frequency must be four times higher than lsi_ker_ck/lse_ck (period (LSI/LSE) ≥ 4 * period (HCLK).
pub const fn set_systicksel(&mut self, val: Systicksel)
pub const fn set_systicksel(&mut self, val: Systicksel)
SYSTICK clock source selection Note: rcc_hclk frequency must be four times higher than lsi_ker_ck/lse_ck (period (LSI/LSE) ≥ 4 * period (HCLK).
pub const fn set_usbsel(&mut self, val: Usbsel)
pub const fn set_usbsel(&mut self, val: Usbsel)
USB kernel clock source selection
pub const fn set_sdmmc1sel(&mut self, val: Sdmmcsel)
pub const fn set_sdmmc1sel(&mut self, val: Sdmmcsel)
SDMMC1 kernel clock source selection
pub const fn set_sdmmc2sel(&mut self, val: Sdmmcsel)
pub const fn set_sdmmc2sel(&mut self, val: Sdmmcsel)
SDMMC2 kernel clock source selection
pub const fn set_i2c1sel(&mut self, val: I2csel)
pub const fn set_i2c1sel(&mut self, val: I2csel)
I2C1 kernel clock source selection
pub const fn set_i2c2sel(&mut self, val: I2csel)
pub const fn set_i2c2sel(&mut self, val: I2csel)
I2C2 kernel clock source selection
pub const fn set_i2c3sel(&mut self, val: I2c34sel)
pub const fn set_i2c3sel(&mut self, val: I2c34sel)
I2C3 kernel clock source selection
pub const fn set_i2c4sel(&mut self, val: I2c34sel)
pub const fn set_i2c4sel(&mut self, val: I2c34sel)
I2C4 kernel clock source selection
pub const fn set_i3c1sel(&mut self, val: I2csel)
pub const fn set_i3c1sel(&mut self, val: I2csel)
I3C1 kernel clock source selection
pub const fn set_i3c2sel(&mut self, val: I2c34sel)
pub const fn set_i3c2sel(&mut self, val: I2c34sel)
I3C2 kernel clock source selection